跳到主要内容

Error

搜索

结构体 Error 

源代码
pub struct Error(/* 私有字段 */);
展开描述

计时器实现遇到的错误。

目前,可能发生两种不同的错误:

  • 当尝试计时器操作,但计时器实例已被 drop 时,会发生 shutdown。在这种情况下,操作将永远无法完成,并返回 shutdown 错误。这是一个永久性错误,即一旦观察到该错误,将来计时器操作将永远不会成功。

  • 当尝试计时器操作,但计时器实例当前正在处理最大数量的未完成 sleep 实例时,会发生 at_capacity。在这种情况下,操作当前无法执行,并返回 at_capacity。这是一个暂时性错误,即在将来的某个时刻,如果再次尝试该操作,它可能会成功。观察到该错误的调用者应尝试减载。一种方法是 drop 发出计时器操作的 future。

实现

源代码

impl Error

源代码

pub fn shutdown() -> Error

创建一个表示已关闭计时器的错误。

源代码

pub fn is_shutdown(&self) -> bool

如果错误是由计时器关闭引起的,则返回 true

源代码

pub fn at_capacity() -> Error

创建一个表示计时器已达到容量的错误。

源代码

pub fn is_at_capacity(&self) -> bool

如果错误是由计时器达到容量引起的,则返回 true

源代码

pub fn invalid() -> Error

创建一个表示计时器配置错误的错误。

源代码

pub fn is_invalid(&self) -> bool

如果错误是由计时器配置错误引起的,则返回 true

trait 实现

源代码

impl Clone for Error

源代码

fn clone(&self) -> Error

返回值的副本。 更多信息
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
源代码

impl Debug for Error

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
源代码

impl Display for Error

源代码

fn fmt(&self, fmt: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
源代码

impl Error for Error

1.30.0 · 源代码

fn source(&self) -> Option<&(dyn Error + 'static)>

返回此错误的更底层来源(若有)。 更多信息
1.0.0 · 源代码

fn description(&self) -> &str

👎Deprecated since 1.42.0: use the Display impl or to_string()
1.0.0 · 源代码

fn cause(&self) -> Option<&dyn Error>

👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
源代码

fn provide<'a>(&'a self, request: &mut Request<'a>)

🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports. 更多信息
源代码

impl Copy for Error

自动 trait 实现



impl Freeze for Error



impl RefUnwindSafe for Error



impl Send for Error



impl Sync for Error



impl Unpin for Error



impl UnsafeUnpin for Error



impl UnwindSafe for Error

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换是 From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获得所有权后的类型。
源代码

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
源代码

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

Converts the given value to a String. 更多信息
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。